==> client-java-api-fluent-15.0.1-sources.jar: io/kubernetes/client/openapi/models/V1beta2FlowSchemaBuilder.java <==
/*
Copyright 2022 The Kubernetes Authors.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;

public class V1beta2FlowSchemaBuilder extends V1beta2FlowSchemaFluentImpl<V1beta2FlowSchemaBuilder>
    implements VisitableBuilder<
        io.kubernetes.client.openapi.models.V1beta2FlowSchema,
        io.kubernetes.client.openapi.models.V1beta2FlowSchemaBuilder> {
  public V1beta2FlowSchemaBuilder() {
    this(false);
  }

  public V1beta2FlowSchemaBuilder(Boolean validationEnabled) {
    this(new V1beta2FlowSchema(), validationEnabled);
  }

  public V1beta2FlowSchemaBuilder(V1beta2FlowSchemaFluent<?> fluent) {
    this(fluent, false);
  }

  public V1beta2FlowSchemaBuilder(
      io.kubernetes.client.openapi.models.V1beta2FlowSchemaFluent<?> fluent,
      java.lang.Boolean validationEnabled) {
    this(fluent, new V1beta2FlowSchema(), validationEnabled);
  }

  public V1beta2FlowSchemaBuilder(
      io.kubernetes.client.openapi.models.V1beta2FlowSchemaFluent<?> fluent,
      io.kubernetes.client.openapi.models.V1beta2FlowSchema instance) {
    this(fluent, instance, false);
  }

  public V1beta2FlowSchemaBuilder(
      io.kubernetes.client.openapi.models.V1beta2FlowSchemaFluent<?> fluent,
      io.kubernetes.client.openapi.models.V1beta2FlowSchema instance,
      java.lang.Boolean validationEnabled) {
    this.fluent = fluent;
    fluent.withApiVersion(instance.getApiVersion());

    fluent.withKind(instance.getKind());

    fluent.withMetadata(instance.getMetadata());

    fluent.withSpec(instance.getSpec());

    fluent.withStatus(instance.getStatus());

    this.validationEnabled = validationEnabled;
  }

  public V1beta2FlowSchemaBuilder(io.kubernetes.client.openapi.models.V1beta2FlowSchema instance) {
    this(instance, false);
  }

  public V1beta2FlowSchemaBuilder(
      io.kubernetes.client.openapi.models.V1beta2FlowSchema instance,
      java.lang.Boolean validationEnabled) {
    this.fluent = this;
    this.withApiVersion(instance.getApiVersion());

    this.withKind(instance.getKind());

    this.withMetadata(instance.getMetadata());

    this.withSpec(instance.getSpec());

    this.withStatus(instance.getStatus());

    this.validationEnabled = validationEnabled;
  }

  io.kubernetes.client.openapi.models.V1beta2FlowSchemaFluent<?> fluent;
  java.lang.Boolean validationEnabled;

  public io.kubernetes.client.openapi.models.V1beta2FlowSchema build() {
    V1beta2FlowSchema buildable = new V1beta2FlowSchema();
    buildable.setApiVersion(fluent.getApiVersion());
    buildable.setKind(fluent.getKind());
    buildable.setMetadata(fluent.getMetadata());
    buildable.setSpec(fluent.getSpec());
    buildable.setStatus(fluent.getStatus());
    return buildable;
  }
}

==> client-java-api-fluent-17.0.0-sources.jar: io/kubernetes/client/openapi/models/V1beta2FlowSchemaBuilder.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.Boolean;
public class V1beta2FlowSchemaBuilder extends V1beta2FlowSchemaFluentImpl<V1beta2FlowSchemaBuilder> implements VisitableBuilder<V1beta2FlowSchema,V1beta2FlowSchemaBuilder>{
  public V1beta2FlowSchemaBuilder() {
    this(false);
  }
  public V1beta2FlowSchemaBuilder(Boolean validationEnabled) {
    this(new V1beta2FlowSchema(), validationEnabled);
  }
  public V1beta2FlowSchemaBuilder(V1beta2FlowSchemaFluent<?> fluent) {
    this(fluent, false);
  }
  public V1beta2FlowSchemaBuilder(V1beta2FlowSchemaFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new V1beta2FlowSchema(), validationEnabled);
  }
  public V1beta2FlowSchemaBuilder(V1beta2FlowSchemaFluent<?> fluent,V1beta2FlowSchema instance) {
    this(fluent, instance, false);
  }
  public V1beta2FlowSchemaBuilder(V1beta2FlowSchemaFluent<?> fluent,V1beta2FlowSchema instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion());

    fluent.withKind(instance.getKind());

    fluent.withMetadata(instance.getMetadata());

    fluent.withSpec(instance.getSpec());

    fluent.withStatus(instance.getStatus());

    this.validationEnabled = validationEnabled; 
  }
  public V1beta2FlowSchemaBuilder(V1beta2FlowSchema instance) {
    this(instance,false);
  }
  public V1beta2FlowSchemaBuilder(V1beta2FlowSchema instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion());

    this.withKind(instance.getKind());

    this.withMetadata(instance.getMetadata());

    this.withSpec(instance.getSpec());

    this.withStatus(instance.getStatus());

    this.validationEnabled = validationEnabled; 
  }
  V1beta2FlowSchemaFluent<?> fluent;
  Boolean validationEnabled;
  public V1beta2FlowSchema build() {
    V1beta2FlowSchema buildable = new V1beta2FlowSchema();
    buildable.setApiVersion(fluent.getApiVersion());
    buildable.setKind(fluent.getKind());
    buildable.setMetadata(fluent.getMetadata());
    buildable.setSpec(fluent.getSpec());
    buildable.setStatus(fluent.getStatus());
    return buildable;
  }
  
}
